@@ -2,6 +2,7 @@ from django.core.management.commands.runserver import Command as RunServerComman
 from django_pdb.middleware import PdbMiddleware
 from optparse import make_option
 
+
 class Command(RunServerCommand):
     """
     Identical to Django's standard 'runserver' management command,
@@ -10,6 +11,8 @@ class Command(RunServerCommand):
     option_list = RunServerCommand.option_list + (
         make_option('--pdb', action='store_true', dest='pdb', default=False,
             help='Drop into pdb shell on at the start of any view.'),
+        make_option('--ipdb', action='store_true', dest='ipdb', default=False,
+            help='Drop into ipdb shell on at the start of any view.'),
     )
 
     def handle(self, *args, **options):
@@ -17,13 +20,18 @@ class Command(RunServerCommand):
         from django.conf import settings
 
         pdb_option = options.pop('pdb')
-     
-        if pdb_option or settings.DEBUG:
-            settings.MIDDLEWARE_CLASSES += ('django_pdb.middleware.PdbMiddleware',)
-        
+        ipdb_option = options.pop('ipdb')
+
+        middleware = 'django_pdb.middleware.PdbMiddleware'
+        if ((pdb_option or settings.DEBUG)
+            and middleware not in settings.MIDDLEWARE_CLASSES):
+            settings.MIDDLEWARE_CLASSES += (middleware,)
+
         # If --pdb is specified then always break at the start of views.
-        # Otherwise break only if a 'pdb' query parameter is set in the url.  
+        # Otherwise break only if a 'pdb' query parameter is set in the url.
         if pdb_option:
-            PdbMiddleware.always_break = True
+            PdbMiddleware.always_break = 'pdb'
+        elif ipdb_option:
+            PdbMiddleware.always_break = 'ipdb'
 
         super(Command, self).handle(*args, **options)
